<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineParallel</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz linię, łuk lub okrąg</translation>
    </message>
    <message>
        <location filename="../LineParallel.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Odległość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Ilość:</translation>
    </message>
    <message>
        <location filename="../LineParallelInit.js" line="+2"/>
        <source>Para&amp;llel (with Distance)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Równoległa (w odległości)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje linię równoległą do istniejącej linii lub koncentryczny łuk, okrąg</translation>
    </message>
</context>
</TS>
